@@ -127,29 +127,8 @@ OC.L10N.register(
     "New owner" : "Chủ sở hữu mới",
     "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết tới",
     "Choose {file}" : "Chọn {file}",
-    "Share" : "Chia sẻ",
-    "Shared by link" : "Được chia sẻ với liên kết",
-    "Shared" : "Đã chia sẻ",
-    "Switch to list view" : "Chuyển sang chế độ xem danh sách",
-    "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
-    "Upload was cancelled by user" : "Tải lên bị hủy bởi người dùng",
-    "Not enough free space" : "Không đủ dung lượng trống",
-    "Operation is blocked by access control" : "Thao tác bị chặn bởi kiểm soát truy cập",
-    "Error during upload: {message}" : "Lỗi khi đang tải lên: {message}",
-    "Error during upload, status code {status}" : "Lỗi khi đang tải lên, mã lỗi {status}",
-    "Unknown error during upload" : "Lỗi không xác định trong quá trình tải lên",
-    "Loading current folder" : "Đang tải thư mục hiện tại",
-    "Retry" : "Thử lại",
-    "No files in here" : "Không có tệp nào",
-    "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
-    "Go back" : "Quay lại",
-    "Views" : "Lượt xem",
-    "Files settings" : "Cài đặt tập tin",
-    "Your files" : "Tập tin của bạn",
-    "Open in files" : "Mở trong Tệp",
-    "File cannot be accessed" : "Không thể truy cập tập tin",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
     "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
+    "Files settings" : "Cài đặt tập tin",
     "General" : "Cài đặt chung",
     "All files" : "Tất cả tệp tin",
     "Sort favorites first" : "Sắp xếp mục yêu thích trước",
@@ -167,10 +146,23 @@ OC.L10N.register(
     "Deselect all" : "Bỏ chọn tất cả",
     "Navigation" : "Điều hướng",
     "View" : "Xem",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
-    "Files compatibility" : "Khả năng tương thích của tập tin",
-    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
+    "Share" : "Chia sẻ",
+    "Shared by link" : "Được chia sẻ với liên kết",
+    "Shared" : "Đã chia sẻ",
+    "Switch to list view" : "Chuyển sang chế độ xem danh sách",
+    "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
+    "Upload was cancelled by user" : "Tải lên bị hủy bởi người dùng",
+    "Not enough free space" : "Không đủ dung lượng trống",
+    "Operation is blocked by access control" : "Thao tác bị chặn bởi kiểm soát truy cập",
+    "Error during upload: {message}" : "Lỗi khi đang tải lên: {message}",
+    "Error during upload, status code {status}" : "Lỗi khi đang tải lên, mã lỗi {status}",
+    "Unknown error during upload" : "Lỗi không xác định trong quá trình tải lên",
+    "Loading current folder" : "Đang tải thư mục hiện tại",
+    "Retry" : "Thử lại",
+    "No files in here" : "Không có tệp nào",
+    "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
+    "Go back" : "Quay lại",
+    "Views" : "Lượt xem",
     "You" : "Bạn",
     "Shared multiple times with different people" : "Được chia sẻ nhiều lần với những người khác nhau",
     "Error while loading the file data" : "Lỗi xảy ra trong khi tải dữ liệu tệp",
@@ -178,6 +170,14 @@ OC.L10N.register(
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "Add to favorites" : "Thêm vào ưa thích",
     "Tags" : "Nhãn",
+    "Your files" : "Tập tin của bạn",
+    "Open in files" : "Mở trong Tệp",
+    "File cannot be accessed" : "Không thể truy cập tập tin",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
+    "Files compatibility" : "Khả năng tương thích của tập tin",
+    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
     "Blank" : "Trống",
     "Unable to create new file from template" : "Không thể tạo tệp mới từ mẫu",
     "Pick a template for {name}" : "Hãy chọn một mẫu cho {name}",
@@ -198,8 +198,6 @@ OC.L10N.register(
     "Confirm deletion" : "Xác nhận xoá",
     "Cancel" : "Hủy bỏ",
     "Download" : "Tải về",
-    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
     "Destination is not a folder" : "Đích đến không phải là một thư mục",
     "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
@@ -277,86 +275,10 @@ OC.L10N.register(
     "Select all" : "Chọn tất cả",
     "Upload too large" : "Tập tin tải lên quá lớn",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
-    "File could not be found" : "Tệp tin không tồn tại",
-    "Show list view" : "Hiển thị chế độ xem danh sách",
-    "Show grid view" : "Hiển thị chế độ xem lưới",
-    "Close" : "Đóng",
-    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
-    "This will stop your current uploads." : "Hành động này sẽ dừng các tải lên hiện hành.",
-    "Upload cancelled." : "Hủy tải lên",
-    "Processing files …" : "Đang xử lý các tệp tin...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
-    "Target folder \"{dir}\" does not exist any more" : "Thư mục đích \"{dir}\" không còn tồn tại",
-    "An unknown error has occurred" : "Một lỗi không rõ đã xảy ra",
-    "File could not be uploaded" : "Không thể tải lên tập tin",
-    "Uploading …" : "Đang tải lên …",
-    "Uploading … ({currentNumber}/{total})" : "Đang tải lên … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Tải lên mục đó không được hỗ trợ",
-    "Error when assembling chunks, status code {status}" : "Lỗi khi lắp ráp khối, mã trạng thái {status}",
-    "Choose target folder" : "Chọn thư mục đích",
-    "Set reminder" : "Thiết lập nhắc nhở",
-    "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
-    "Open" : "Mở",
-    "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Vui lòng chọn (các) thẻ để thêm vào lựa chọn",
-    "Apply tag(s) to selection" : "Áp dụng (các) thẻ cho lựa chọn",
-    "Select directory \"{dirName}\"" : "Chọn thư mục \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Chọn tệp tin \"{fileName}\"",
-    "Unable to determine date" : "Không thể xác định ngày",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
-    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
-    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
-    "copy" : "sao chép",
-    "Could not copy \"{file}\", target exists" : "Không thể sao chép \"{file}\",  tệp tin đích đã tồn tại",
-    "Could not copy \"{file}\"" : "Không thể sao chép tệp tin \"{file}\"",
-    "Copied {origin} inside {destination}" : "Được sao chép {origin} vào trong {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Đã sao chép {origin} và {nbfiles} các file vào trong {destination}",
-    "{newName} already exists" : "{newName} đã có",
-    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
-    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
-    "Could not fetch file details \"{file}\"" : "Không thể lấy chi tiết tệp \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Nhập nhiều hơn hai ký tự để tìm kiếm trong các thư mục khác",
-    "{dirs} and {files}" : "{dirs} và {files}",
-    "_including %n hidden_::_including %n hidden_" : ["Bao gồm %n ẩn"],
-    "You do not have permission to upload or create files here" : "Bạn không đủ quyền để Tải lên hoặc Tạo tập tin ở đây",
-    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
-    "New" : "Tạo mới",
-    "New file/folder menu" : "Menu tập tin/thư mục mới",
-    "Select file range" : "Chọn phạm vi tệp",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} được sử dụng",
-    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
-    "File name cannot be empty." : "Tên file không được rỗng",
-    "\"/\" is not allowed inside a file name." : "\"/\" không được phép có trong tên tệp.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Bộ nhớ của {owner} đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Thư mục nhóm \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Bộ nhớ ngoài \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Bộ nhớ của bạn đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Dung lượng lưu trữ {owner} gần đầy ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Thư mục nhóm \"{mountPoint}\" gần đầy ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Bộ nhớ ngoài \"{mountPoint}\" gần đầy ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Dung lượng lưu trữ của bạn gần đầy rồi ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["khớp với \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Đã sao chép đường dẫn trực tiếp(Chỉ áp dụng đối với người dùng có quyền truy cập vào thư mục/tệp tin)",
-    "Path" : "Đường dẫn",
-    "Favored" : "Được ưa thích",
-    "Favor" : "Ưa thích",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với những người dùng có quyền truy cập vào tệp / thư mục này)",
-    "Upload file" : "Tải lên tập tin",
-    "Not favored" : "Không được ưa thích",
-    "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
     "Upload (max. %s)" : "Tải lên (tối đa %s)",
-    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
-    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
     "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
-    "Filter filenames…" : "Lọc tên tệp…",
+    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
+    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
     "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
     "Enable the grid view" : "Bật chế độ xem lưới",
     "Enable folder tree" : "Bật cây thư mục",
@@ -364,20 +286,16 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
     "Deletion cancelled" : "Thao tác xóa bị hủy",
+    "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
+    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
     "Move cancelled" : "Di chuyển bị dừng",
     "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
     "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
     "Open details" : "Mở chi tiết",
     "Photos and images" : "Ảnh",
     "New folder creation cancelled" : "Lỗi tạo thư mục",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["thư mục {folderCount}"],
-    "_{fileCount} file_::_{fileCount} files_" : ["tệp {fileCount}"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tệp và thư mục {folderCount}"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["tệp {fileCount} và 1 thư mục"],
-    "{fileCount} files and {folderCount} folders" : "Tệp {fileCount} và thư mục {folderCount}",
-    "All folders" : "Tất cả tệp tin",
-    "Personal Files" : "Tệp tin cá nhân",
-    "Text file" : "Tập tin văn bản",
-    "New text file.txt" : "Tệp văn bản mới.txt"
+    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
+    "All folders" : "Tất cả tệp tin"
 },
 "nplurals=1; plural=0;");
